(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     66691,       1842]
NotebookOptionsPosition[     25098,        890]
NotebookOutlinePosition[     62296,       1700]
CellTagsIndexPosition[     62253,       1697]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["The SinSurface application example", "Title"],

Cell["\<\
Copyright \[Copyright] MathCore AB 1999-2004\
\>", "Copyright"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 "Below we describe the SinSurface program example. The actual computation is \
performed by the functions ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ", ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " and their help functions."
}], "Text"],

Cell[TextData[{
 "The two functions ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " and ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " in the SinSurface package will be translated to C++ together with the \
declaration of the global array ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 "."
}], "Text"],

Cell[TextData[{
 "The array ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 " represents a 21x21 grid on which which the numeric function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " will be computed."
}], "Text"],

Cell[TextData[{
 "The function ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " accepts four arguments which are coordinates that describe a square in the \
x-y plane, and one counter (",
 StyleBox["iter",
  FontFamily->"Courier"],
 ") to make the function repeat the computation as many times as necessary \
for measuring execution time. For each point on a 21x21 grid in that square, \
the numeric function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is called to compute a value that is stored as a matrix element in the \
matrix representing the grid."
}], "Text"],

Cell[TextData[{
 "The function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " computes essentially the same values as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["Sin",
     FontFamily->"Courier"], "(", 
    RowBox[{"x", "+", "y"}], ")"}], TraditionalForm]]],
 ", but in a more complicated way using a rather large expression obtained \
through conversion of the arguments into polar coordinates (through ",
 StyleBox["arcTan",
  FontFamily->"Courier"],
 ") and then using series expansion of both ",
 StyleBox["Sin",
  FontFamily->"Courier"],
 " and ",
 StyleBox["Cos",
  FontFamily->"Courier"],
 " in 10 terms. The resulting large symbolic expression (more than a page) \
becomes the body of ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 ", and is then used as input to ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 " (see Section 7.5 and Section 7.6.3 in the manual) to generate efficient \
Fortran90 code."
}], "Text"],

Cell[TextData[{
 "The SinSurface example application computes a function (here ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 ") over a 2-D grid. The function values are first stored in the matrix ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 " before being plotted. The execution of compiled Fortran90 code for the \
function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is approximately 500-1000 times faster than evaluating the same function \
interpretively within Mathematica."
}], "Text"],

Cell["\<\
To run this example, evaluate this notebook cell by cell or the whole at once.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell["Load the MathCode package", "Subsection"],

Cell["\<\
First put a Needs statement, to make sure that the MathCode application is \
loaded:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check current directory", "Subsection"],

Cell["\<\
You might want to set the directory to some place where all generated files \
are put, e.g. the one below, or some other directory.\
\>", "Text"],

Cell["\<\
SetDirectory[$MCRoot<>$PathnameSeparator<>\"DemosF90\"<>$PathnameSeparator<>\"\
SinSurface\"];\
\>", "Input"],

Cell["Check whether this file is in the current directory.", "Text"],

Cell["ExistFileQ[\"SinSurfaceF90.nb\"]", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Start of the SinSurface package", "Section"],

Cell["\<\
The SinSurface package starts in the usual way by a BeginPackage declaration \
which references other packages.The MathCodeContexts are needed in order to \
call the code generation related functions. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BeginPackage", "[", 
     RowBox[{"\"\<SinSurface`\>\"", ",", " ", 
      RowBox[{"{", "MathCodeContexts", "}"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"General", "::", "spell"}], "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"General", "::", "spell1"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "\"\<SinSurface`*\>\"", "]"}], ";"}]}], 
  " "}]], "Input"],

Cell[CellGroupData[{

Cell["Exported symbols", "Subsection"],

Cell[TextData[{
 "Define possibly exported symbols. Even though it is not necessary here, we \
enclose these names within a ",
 StyleBox["Begin[\"SinSurface\[OpenCurlyQuote]\"] ... End[]",
  FontFamily->"Courier"],
 " kind of \[OpenCurlyDoubleQuote]context bracket\[CloseCurlyDoubleQuote], \
since this can be put into a cell in the notebook, and conveniently \
re-evaluated (only this cell!) when a new name is added to the list below."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<SinSurface`\>\"", "]"}], ";"}], "\n", 
 RowBox[{" ", 
  RowBox[{"xyMatrix", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"calcPlot", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"sinFun1", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"sinFun2", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"arcTan", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"sin", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"cos", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"plot", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"cplus", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"plotfile", ";"}]}], "\n", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting compilation options", "Subsection"],

Cell[TextData[{
 "This defines how the functions and variables in the package should be \
compiled to Fortran90. By default, all typed variables and functions are \
compiled. However, the compilation process can be controlled in a more \
detailed manner by setting compilation options via ",
 StyleBox["SetCompilationOptions",
  FontFamily->"Courier"],
 ". For example, in this package the function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " should be symbolically evaluated before being translated to code since it \
contains symbolic operations; the functions ",
 StyleBox["sin",
  FontFamily->"Courier"],
 ", ",
 StyleBox["cos",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["arcTan",
  FontFamily->"Courier"],
 " should not be compiled at all since they are expanded within the body of \
",
 StyleBox["sinFun2.",
  FontFamily->"Courier"],
 " The remaining typed function, ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ", will be compiled in the normal way."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCompilationOptions", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"EvaluateFunctions", "->", 
     RowBox[{"{", "sinFun2", "}"}]}], ",", "\n", "  ", 
    RowBox[{"UnCompiledFunctions", "->", 
     RowBox[{"{", 
      RowBox[{"sin", ",", "cos", ",", "arcTan"}], "}"}]}], ",", "\n", "  ", 
    RowBox[{"Language", "\[Rule]", "\"\<Fortran90\>\""}]}], "\n", "]"}], 
  ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The body of the SinSurface package", "Section"],

Cell["\<\
Begin the implementation section of the SinSurface package, where functions \
are defined. This is usually private, to avoid accidental name shadowing due \
to identical local variables in several packages.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Begin", "[", "\"\<SinSurface`Private`\>\"", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Global variables", "Subsection"],

Cell["Declare global variables.", "Text"],

Cell[TextData[{
 StyleBox["Declare",
  FontColor->RGBColor[0, 0, 1]],
 "[\n  ",
 StyleBox["Real[21,21]",
  FontColor->RGBColor[0, 0, 1]],
 "  xyMatrix \n];"
}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["sin, cos", "Subsection"],

Cell["Taylor-expanded sin and cos functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sin", "[", 
       RowBox[{"Real", " ", "x_"}], "]"}], "\[Rule]", "Real"}], ":=", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"Sin", "[", "z", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}], "/.", 
      RowBox[{"z", "\[Rule]", "x"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cos", "[", 
       RowBox[{"Real", " ", "x_"}], "]"}], "\[Rule]", "Real"}], ":=", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"Cos", "[", "z", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}], "/.", 
      RowBox[{"z", "\[Rule]", "x"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.510652814797831*^9, 3.510652820750766*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["arcTan", "Subsection"],

Cell[TextData[{
 "Conversion of grid point to an angle, called by ",
 StyleBox["sinFun2.",
  FontFamily->"Courier"]
}], "Text",
 CellChangeTimes->{{3.510652600867177*^9, 3.510652608835672*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"arcTan", "[", 
      RowBox[{
       RowBox[{"Real", " ", "x_"}], ",", 
       RowBox[{"Real", " ", "y_"}]}], "]"}], "\[Rule]", "Real"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"x", "<", "0"}], ",", "Pi", ",", "0"}], "]"}], 
      "\[IndentingNewLine]", "+", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"x", "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"Sign", "[", "y", "]"}], "*", 
         RowBox[{"Pi", "/", "2"}]}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"y", "/", "x"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
     ")"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5106526060076375`*^9, 3.5106526311943316`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["sinFun2", "Subsection"],

Cell[TextData[{
 "The function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is the function to be computed and plotted, called by ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ". It provides a more complicated and computationally heavier way (series \
expansion) to calculate approximately the same as ",
 StyleBox["Sin[x+y]",
  FontFamily->"Courier"],
 ". This gives an example of a combination of symbolic and numeric operations \
as well as a rather standard mix of arithmetic operations. The expanded \
symbolic expression which comprises the body of ",
 StyleBox["SinFun2",
  FontFamily->"Courier"],
 " is between 1 and 2 pages long when printed."
}], "Text"],

Cell[TextData[{
 "Note that the types of local variables to ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " need not necessarily be declared since ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 " will symbolically expand the whole body before translating it to C++ code. "
}], "Text"],

Cell["\<\
Note also that a function to be symbolically expanded before final code \
generation should be without side effects, e.g. assignment to global \
variables or input/output, since otherwise these actions will be performed \
during the symbolic evaluation, which would be problematic.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sinFun2", "[", 
      RowBox[{
       RowBox[{"Real", " ", "x_"}], ",", 
       RowBox[{"Real", " ", "y_"}]}], "]"}], "\[Rule]", "Real"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Real", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "xx", ",", "yy"}], "}"}]}], "}"}], ",", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"r", "*", 
         RowBox[{"cos", "[", 
          RowBox[{"arcTan", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"yy", "=", 
        RowBox[{"r", "*", 
         RowBox[{"sin", "[", 
          RowBox[{"arcTan", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sin", "[", 
        RowBox[{"xx", "+", "yy"}], "]"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5106526584434595`*^9, 3.5106526649432516`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["calcPlot ", "Subsection"],

Cell[TextData[{
 "The function ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " calculates data for a plot of sinFun2 over a 21x21 grid, which is returned \
as a 21x21 array."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"calcPlot", "[", 
      RowBox[{
       RowBox[{"Real", " ", "xmin_"}], ",", 
       RowBox[{"Real", " ", "xmax_"}], ",", 
       RowBox[{"Real", " ", "ymin_"}], ",", 
       RowBox[{"Real", " ", "ymax_"}], ",", 
       RowBox[{"Integer", " ", "iter_"}]}], "]"}], "\[Rule]", 
     RowBox[{"Real", "[", 
      RowBox[{"_", ",", "_"}], "]"}]}], ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Integer", " ", "n"}], "=", "20"}], ",", 
        RowBox[{"Real", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ",", 
        RowBox[{"Integer", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j", ",", "count"}], "}"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"count", "=", "1"}], ",", 
         RowBox[{"count", "\[LessEqual]", "iter"}], ",", 
         RowBox[{"count", "=", 
          RowBox[{"count", "+", "1"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ",", 
           RowBox[{"i", "\[LessEqual]", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}], ",", 
           RowBox[{"i", "=", 
            RowBox[{"i", "+", "1"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"j", "=", "1"}], ",", 
             RowBox[{"j", "\[LessEqual]", 
              RowBox[{"(", 
               RowBox[{"n", "+", "1"}], ")"}]}], ",", 
             RowBox[{"j", "=", 
              RowBox[{"j", "+", "1"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"x", "=", 
               RowBox[{"xmin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"xmax", "-", "xmin"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"i", "-", "1"}], ")"}], "/", "n"}]}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"y", "=", 
               RowBox[{"ymin", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"ymax", "-", "ymin"}], ")"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"j", "-", "1"}], ")"}], "/", "n"}]}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"xyMatrix", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
               RowBox[{"sinFun2", "[", 
                RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}]}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", "xyMatrix"}]}], "]"}]}], ";"}]}]], "Input",\

 CellChangeTimes->{{3.510652687208164*^9, 3.5106527104574203`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["End of the SinSurface package", "Subsection"],

Cell["\<\
End[];
EndPackage[]; \
\>", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Execution", "Section"],

Cell[TextData[{
 "We first execute the application interpretively within ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and then compile the key function and execute the application again. Then \
we compile the application to C++, build an executable, and call the same \
functions from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " via ",
 StyleBox["MathLink",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " evaluation"
}], "Subsection"],

Cell[TextData[{
 "Let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate a plot."
}], "Text"],

Cell["meval = Timing[plot = calcPlot[-2., 2., -2., 2., 1] ][[1]]", "Input"],

Cell["Perform the plot.", "Text"],

Cell["ListPlot3D[plot] ", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " standard ",
 StyleBox["Compile[]",
  FontFamily->"Courier"]
}], "Subsection"],

Cell[TextData[{
 "Redefine ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " to become a compiled version, using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " standard ",
 StyleBox["Compile[]",
  FontFamily->"Courier"],
 "."
}], "Text"],

Cell["sinFun2 = Compile[{x, y}, Evaluate[sinFun2[x, y]]]; ", "Input"],

Cell["Timing[plot = calcPlot[-2., 2., -2., 2., 1]; ]", "Input"],

Cell["compeval = %[[1]]; ", "Input"],

Cell["sinFun2 =. ", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Fully Expanded Symbolic expression to be compiled to Fortran90\
\>", "Subsection"],

Cell[TextData[{
 "This shows the size of ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " fully expanded. Be prepared for a big output."
}], "Text"],

Cell["sinFun2[a, b]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the MathCode code generator", "Subsection"],

Cell["Compile the SinSurface package:", "Text"],

Cell[BoxData[
 RowBox[{"CompilePackage", "[", "\"\<SinSurface\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The generated Fortran90 code", "Subsection"],

Cell[TextData[{
 "Below follows the generated Fortran90 code from the SinSurface program. \
Notice that the package name becomes a module name  for  the generated \
Fortran90 function. Thus the Mathematica function ",
 StyleBox["SinSurface\[OpenCurlyQuote]sinFun2",
  FontFamily->"Courier"],
 " becomes ",
 StyleBox["sinFun2",
  FontFamily->"Courier New"],
 StyleBox[" of module ",
  FontFamily->"Times New Roman"],
 StyleBox["mc_SinSurface ",
  FontFamily->"Courier New"],
 " in Fortran90."
}], "Text"],

Cell[TextData[{
 "The generated code from ",
 StyleBox["SinSurface\[OpenCurlyQuote]sinFun2",
  FontFamily->"Courier"],
 " is produced from a large expression by ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 ". Common subexpression elimination is performed by the code generator, \
producing many temporary variables and subexpressions which can be seen in \
the body of the Fortran90 function ",
 StyleBox["sinFun2.",
  FontFamily->"Courier"]
}], "Text"],

Cell[TextData[{
 "By contrast, the Fortran90 code in the body of function ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " produced by ",
 StyleBox["CompileFunction",
  FontFamily->"Courier"],
 " from the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["SinSurface\[OpenCurlyQuote]calcPlot",
  FontFamily->"Courier"],
 ", follows the structure of the original code quite closely."
}], "Text"],

Cell["\<\
We give a command to type out the text of the generated Fortran90 file:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<SinSurface.f90\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compiling and linking the Fortran90 code", "Subsection"],

Cell[TextData[{
 "The command ",
 StyleBox["MakeBinary",
  FontFamily->"Courier"],
 " compiles the generated Fortran90  code using some Fortran90 compiler (in \
this particular case the Digital Fortran, version 6.0, for Windows). The \
object code is by default linked into  executable ",
 StyleBox["SinSurfaceml.exe",
  FontFamily->"Courier"],
 " for calling the compiled code via ",
 StyleBox["MathLink",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBinary", "[", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installing and connecting to Mathematica", "Subsection"],

Cell[TextData[{
 "The command ",
 StyleBox["InstallCode",
  FontFamily->"Courier"],
 " installs and connects the external process containing the compiled and \
linked SinSurface code."
}], "Text"],

Cell[BoxData[
 RowBox[{"installedLink", "=", 
  RowBox[{"InstallCode", "[", "\"\<SinSurface\>\"", "]"}]}]], "Input"],

Cell["Define a time measurement function called AbsTime:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", 
    RowBox[{"AbsTime", ",", "HoldFirst"}], "]"}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AbsTime", "[", "x_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "  ", 
      RowBox[{"start", ",", "res"}], "\n", " ", "}"}], ",", "\n", "   ", 
     RowBox[{
      RowBox[{"start", " ", "=", " ", 
       RowBox[{"AbsoluteTime", "[", "]"}]}], ";", "\n", "   ", 
      RowBox[{"res", "=", "x"}], ";", "\n", "   ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"AbsoluteTime", "[", "]"}], "-", "start"}], ")"}], " ", 
         "Second"}], ",", "res"}], "}"}]}]}], "\n", "]"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Execution of generated Fortran90 code", "Subsection"],

Cell["Perform the computation and the plot:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"plot", " ", "=", " ", 
     RowBox[{"calcPlot", "[", 
      RowBox[{
       RowBox[{"-", "2.0"}], ",", "2.0", ",", 
       RowBox[{"-", "2.0"}], ",", "2.0", ",", "3000"}], "]"}]}], ";"}], ")"}],
   " ", "//", " ", "AbsTime"}]], "Input"],

Cell["\<\
Since the external computation was performed 500 times, the time needed for \
one external computation is:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"externaleval", " ", "=", " ", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/", "3000"}]}]], "Input"],

Cell["Just check that we get the right result", "Text"],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", "plot", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Performance Comparison", "Subsection"],

Cell[TextData[{
 "The performance between the three forms of execution are compared in the \
table below. The generated Fortran90 code for this example is roughly \
1000-3000 times faster than standard interpreted ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code, and almost 200-300 times faster than expression code compiled by the \
internal ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["Compile[]",
  FontFamily->"Courier"],
 " command."
}], "Text"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"meval", ",", 
       RowBox[{"meval", "/", "externaleval"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"compeval", ",", 
       RowBox[{"compeval", "/", "externaleval"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"externaleval", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"TableHeadings", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Standard Mathematica\>\"", ",", "\"\<Compile[]\>\"", ",", 
        "\"\<External F90 via MathLink\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Time consumed\>\"", ",", "\"\<Relative\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cleanup", "Section"],

Cell["\<\
Uninstall[installedLink];
CleanMathCodeFiles[Confirm \[Rule] False,CleanAllBut \[Rule] {}]\
\>", "Input"]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{1157, 922},
WindowMargins->{{23, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "\nModify the definitions below to change the default appearance of all \
cells in \na given style.  Make modifications to any definition using \
commands in the \nFormat menu.\n", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "\nThe options defined for the style below will be used at the \
Notebook level.\n", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageHeaderLines -> {True, True}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontSize -> 
             34, FontColor -> GrayLevel[1], Background -> RGBColor[0, 0, 1]], 
            
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 0}, FontSize -> 
             44], 
            Cell[
             StyleData["Title", "Condensed"], CellMargins -> {{0, 0}, {0, 0}},
              FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24, FontTracking -> "Plain", Background -> 
             GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 3}, ParagraphIndent -> -96, CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 6}, 
             ParagraphIndent -> -157, FontSize -> 30], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -78, 
             FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -85, 
             FontSize -> 16, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {30, 10}}, PageBreakBelow -> False, 
             CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{8, 10}, {40, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{9, 10}, {50, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {4, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 6, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold", 
             FontColor -> RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{10, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, FontSize -> 14, FontTracking -> 
             "Plain", FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], 
             CellMargins -> {{12, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{11, 10}, {8, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {4, 40}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{29, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{22, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{21, 0}, {4, 20}}, FontSize -> 11]}, Open]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Text", FontFamily -> "Times"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {4, 4}},
              LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{9, 0}, {4, 4}}, 
             ParagraphSpacing -> {0, 6}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 6}, 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {2, 2}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{9, 0}, {4, 4}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "\nThe cells in this section define styles used for input and output \
to the \nkernel.  Be careful when modifying, renaming, or removing these \
styles, \nbecause the front end associates special meanings with these style \
names.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[1, 1, 0]], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{44, 0}, {6, 6}},
              Background -> GrayLevel[0.8]]}, Closed]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{3, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Output", Background -> 
             RGBColor[1, 0.900008, 0.900008]], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{62, Inherited}, {12, 5}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{40, Inherited}, {4, 1}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{44, 0}, {6, 2}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             CellMargins -> {{52, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {175, 175}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 11, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 8], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {2, 10}}, FontSize -> 16, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Author", "Presentation"], 
             CellMargins -> {{12, 10}, {2, 12}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 20], 
            Cell[
             StyleData["Author", "Condensed"], 
             CellMargins -> {{8, 10}, {1, 4}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{9, 0}, {4, 12}}, ParagraphSpacing -> {0, 6}, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Copyright"], ShowCellBracket -> False, 
             CellMargins -> {{10, 10}, {40, 2}}, FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Presentation"], 
             CellMargins -> {{12, 10}, {50, 2}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["Copyright", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 1}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Printout"], 
             CellMargins -> {{9, 0}, {72, 4}}, FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Example"], CellMargins -> {{12, 10}, {5, 12}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Example", FontFamily -> "Times", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Example", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 20}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Example", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Example", "Printout"], 
             CellMargins -> {{9, 0}, {4, 10}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Definition"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Definition", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Definition", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Definition", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Definition", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.6]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Theorem"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Theorem", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Theorem", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Theorem", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Theorem", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.4]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseMain"], CellFrame -> {{6, 0}, {0, 1}}, 
             CellMargins -> {{12, Inherited}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0.571389, 0.19675, 0.570504], 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 16, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["ExerciseMain", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["ExerciseMain", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["ExerciseMain", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, CellFrameColor -> 
             GrayLevel[0.500008], FontSize -> 14, FontTracking -> "Plain", 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> "\[FilledDownTriangle]", 
             CellMargins -> {{23, Inherited}, {4, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Exercise", "Presentation"], 
             CellMargins -> {{33, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Exercise", "Condensed"], 
             CellMargins -> {{17, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, CellDingbat -> None, 
             CellMargins -> {{9, 0}, {6, 20}}, FontSize -> 11, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseText"], CellMargins -> {{62, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExcersiceText", FontFamily -> "Times"], 
            Cell[
             StyleData["ExerciseText", "Presentation"], 
             CellMargins -> {{74, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["ExerciseText", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 2}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["ExerciseText", "Printout"], 
             CellMargins -> {{54, 0}, {4, 4}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Itemize"], CellDingbat -> "\[FilledSmallCircle]", 
             CellMargins -> {{65, Inherited}, {8, 8}}, FontFamily -> "Times", 
             FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Itemize", "Presentation"], 
             CellMargins -> {{Inherited, 10}, {8, 12}}, LineSpacing -> {1, 0},
              FontSize -> 18], 
            Cell[
             StyleData["Itemize", "Condensed"], 
             CellMargins -> {{Inherited, Inherited}, {2, 12}}, FontSize -> 
             10], 
            Cell[
             StyleData["Itemize", "Printout"], 
             CellMargins -> {{Inherited, 0}, {4, 20}}, FontSize -> 11]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayCode"], CellFrame -> 2, 
             CellMargins -> {{52, 10}, {8, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> True, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             FontWeight -> "Bold", Background -> RGBColor[1, 1, 0]], 
            Cell[
             StyleData["DisplayCode", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["DisplayCode", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["DisplayCode", "Printout"], 
             CellMargins -> {{44, 0}, {6, 6}}, Background -> GrayLevel[0.8]]},
            Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{62, 10}, {2, 10}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 18], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{62, 10}, {2, 10}},
              AutoSpacing -> False, ScriptBaselineShifts -> {0.6, Automatic}, 
             ScriptLevel -> 1, SingleLetterItalics -> False, ZeroWidthTimes -> 
             True], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{12, 10}, {Inherited, 6}}, 
             FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{13, 30}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{9, 0}, {Inherited, 4}}, FontSize -> 9.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section"], 
         Cell[
         "\nThe following styles are useful for numbered equations, figures, \
etc.  They \nautomatically give the cell a FrameLabel containing a reference \
to a \nparticular counter, and also increment that counter.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{62, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Condensed"], 
             CellMargins -> {{52, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["NumberedFigure"]}]], None}}, CounterIncrements -> 
             "NumberedFigure", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedFigure", "Presentation"]], 
            Cell[
             StyleData["NumberedFigure", "Condensed"]], 
            Cell[
             StyleData["NumberedFigure", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Table ", 
                   CounterBox["NumberedTable"]}]], None}}, TextAlignment -> 
             Center, CounterIncrements -> "NumberedTable", 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedTable", "Presentation"]], 
            Cell[
             StyleData["NumberedTable", "Condensed"]], 
            Cell[
             StyleData["NumberedTable", "Printout"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 6], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontWeight -> "Bold"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "\nThe cells below define styles useful for making hypertext \
ButtonBoxes.  The \n\"Hyperlink\" style is for links within the same \
Notebook, or between \nNotebooks.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
         "\nThe following styles are for linking automatically to the on-line \
help \nsystem.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]]}, Closed]]},
      Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (32-bit) (November 7, 2010)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 51, 0, 55, "Title"],
Cell[611, 22, 73, 2, 54, "Copyright"],
Cell[CellGroupData[{
Cell[709, 28, 31, 0, 54, "Section"],
Cell[743, 30, 269, 9, 25, "Text"],
Cell[1015, 41, 318, 12, 25, "Text"],
Cell[1336, 55, 225, 8, 25, "Text"],
Cell[1564, 65, 582, 15, 43, "Text"],
Cell[2149, 82, 964, 30, 61, "Text"],
Cell[3116, 114, 512, 13, 43, "Text"],
Cell[3631, 129, 102, 2, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3770, 136, 33, 0, 54, "Section"],
Cell[CellGroupData[{
Cell[3828, 140, 47, 0, 44, "Subsection"],
Cell[3878, 142, 108, 3, 25, "Text"],
Cell[3989, 147, 74, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4100, 153, 45, 0, 44, "Subsection"],
Cell[4148, 155, 155, 3, 25, "Text"],
Cell[4306, 160, 119, 3, 48, "Input"],
Cell[4428, 165, 68, 0, 25, "Text"],
Cell[4499, 167, 49, 0, 48, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4597, 173, 50, 0, 54, "Section"],
Cell[4650, 175, 225, 4, 25, "Text"],
Cell[4878, 181, 519, 16, 109, "Input"],
Cell[CellGroupData[{
Cell[5422, 201, 38, 0, 44, "Subsection"],
Cell[5463, 203, 449, 8, 43, "Text"],
Cell[5915, 213, 688, 24, 269, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6640, 242, 49, 0, 44, "Subsection"],
Cell[6692, 244, 990, 28, 61, "Text"],
Cell[7685, 274, 415, 10, 129, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8149, 290, 53, 0, 54, "Section"],
Cell[8205, 292, 230, 4, 25, "Text"],
Cell[8438, 298, 102, 2, 48, "Input"],
Cell[CellGroupData[{
Cell[8565, 304, 38, 0, 44, "Subsection"],
Cell[8606, 306, 41, 0, 25, "Text"],
Cell[8650, 308, 169, 7, 82, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8856, 320, 30, 0, 44, "Subsection"],
Cell[8889, 322, 54, 0, 25, "Text"],
Cell[8946, 324, 990, 29, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9973, 358, 28, 0, 44, "Subsection"],
Cell[10004, 360, 193, 5, 25, "Text"],
Cell[10200, 367, 867, 24, 149, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11104, 396, 29, 0, 44, "Subsection"],
Cell[11136, 398, 678, 17, 61, "Text"],
Cell[11817, 417, 309, 8, 25, "Text"],
Cell[12129, 427, 305, 5, 43, "Text"],
Cell[12437, 434, 1217, 35, 129, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13691, 474, 31, 0, 44, "Subsection"],
Cell[13725, 476, 192, 6, 25, "Text"],
Cell[13920, 484, 2970, 77, 249, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16927, 566, 51, 0, 44, "Subsection"],
Cell[16981, 568, 46, 3, 65, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17076, 577, 28, 0, 54, "Section"],
Cell[17107, 579, 420, 13, 43, "Text"],
Cell[CellGroupData[{
Cell[17552, 596, 97, 4, 44, "Subsection"],
Cell[17652, 602, 107, 5, 25, "Text"],
Cell[17762, 609, 75, 0, 48, "Input"],
Cell[17840, 611, 33, 0, 25, "Text"],
Cell[17876, 613, 34, 0, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17947, 618, 156, 7, 45, "Subsection"],
Cell[18106, 627, 248, 11, 25, "Text"],
Cell[18357, 640, 69, 0, 48, "Input"],
Cell[18429, 642, 63, 0, 48, "Input"],
Cell[18495, 644, 36, 0, 48, "Input"],
Cell[18534, 646, 28, 0, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18599, 651, 92, 2, 44, "Subsection"],
Cell[18694, 655, 152, 5, 25, "Text"],
Cell[18849, 662, 30, 0, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18916, 667, 55, 0, 44, "Subsection"],
Cell[18974, 669, 47, 0, 25, "Text"],
Cell[19024, 671, 84, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19145, 677, 50, 0, 44, "Subsection"],
Cell[19198, 679, 503, 14, 43, "Text"],
Cell[19704, 695, 475, 12, 43, "Text"],
Cell[20182, 709, 426, 14, 25, "Text"],
Cell[20611, 725, 95, 2, 25, "Text"],
Cell[20709, 729, 83, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20829, 735, 62, 0, 44, "Subsection"],
Cell[20894, 737, 447, 13, 43, "Text"],
Cell[21344, 752, 76, 2, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21457, 759, 62, 0, 44, "Subsection"],
Cell[21522, 761, 196, 6, 25, "Text"],
Cell[21721, 769, 116, 2, 48, "Input"],
Cell[21840, 773, 66, 0, 25, "Text"],
Cell[21909, 775, 783, 22, 209, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22729, 802, 59, 0, 44, "Subsection"],
Cell[22791, 804, 53, 0, 25, "Text"],
Cell[22847, 806, 301, 9, 48, "Input"],
Cell[23151, 817, 130, 3, 25, "Text"],
Cell[23284, 822, 150, 4, 48, "Input"],
Cell[23437, 828, 55, 0, 25, "Text"],
Cell[23495, 830, 66, 1, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23598, 836, 44, 0, 44, "Subsection"],
Cell[23645, 838, 486, 14, 43, "Text"],
Cell[24134, 854, 755, 22, 69, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24938, 882, 26, 0, 54, "Section"],
Cell[24967, 884, 115, 3, 65, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
